@@ -1,9 +1,15 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #ifndef __GTKSOURCEVIEW_TYPEBUILTINS_H__
 #define __GTKSOURCEVIEW_TYPEBUILTINS_H__ 1
 
+#include <gtksourceview/gtksourcebuffer.h>
+G_BEGIN_DECLS
+#define GTK_TYPE_SOURCE_BRACKET_MATCH_TYPE gtk_source_bracket_match_type_get_type()
+GType gtk_source_bracket_match_type_get_type (void);
+G_END_DECLS
+
 #include <gtksourceview/gtksourceiter.h>
 G_BEGIN_DECLS
 #define GTK_TYPE_SOURCE_SEARCH_FLAGS gtk_source_search_flags_get_type()
@@ -40,5 +46,5 @@ G_END_DECLS
 
 #endif /* __GTKSOURCEVIEW_TYPEBUILTINS_H__ */
 
-/* Generated data ends here */
+
 
